project_slug package - flytrap 0.1.0 documentation

Hide navigation sidebar
Hide table of contents sidebar
Back to top
Toggle table of contents sidebar

# project_slug package

## Submodules

## project_slug.api module

## project_slug.cli module

flytrap.cli.base(target_url: str, ngrok_token: typing.Optional[str] = <typer.models.OptionInfo object>, ngrok: bool = True, speed_test: bool = False, port: int = 8080)

## project_slug.streamlit module

## Module contents

Package for My Awesome Project